@@ -18,7 +18,9 @@ DTS::Assignment::Destination::Connection - a subclass of DTS::Assignment::Destin
       $app->get_db_package(
         { id => '', version_id => '', name => $config->{package}, package_password => '' } );
 
-    foreach my $dyn_prop ( @{ $package->get_dynamic_props } ) {
+	my $iterator = $package->get_dynamic_props();
+
+    while ( my $dyn_prop = $iterator->() ) {
 
         my $iterator = $dyn_props->get_assignments();
 
