@@ -21,13 +21,15 @@ DTS::Assignment::EnvVar - a class to represent a DynamicPropertiesTaskAssignment
       $app->get_db_package(
         { id => '', version_id => '', name => $config->{package}, package_password => '' } );
 
-    foreach my $dyn_prop ( @{ $package->get_dynamic_props } ) {
+	my $iterator = $package->get_dynamic_props();
 
-        foreach my $assignment_prop ( @{ $dyn_prop->get_properties } ) {
+	while  ( my $dyn_prop = $iterator->() ) {
 
-            if ( $assignment_prop->get_type eq 'EnvVar' ) {
+        foreach my $assignment_prop() ( @{ $dyn_prop->get_properties() } ) {
 
-			    print $assignment_prop->to_string, "\n";
+            if ( $assignment_prop->get_type() eq 'EnvVar' ) {
+
+			    print $assignment_prop->to_string(), "\n";
 
             }
 
